==> huaweicloudsdklive-3.0.48-py2.py3-none-any.whl: huaweicloudsdklive/v1/model/show_domain_request.py <==
# coding: utf-8

import pprint
import re

import six





class ShowDomainRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'domain': 'str'
    }

    attribute_map = {
        'domain': 'domain'
    }

    def __init__(self, domain=None):
        """ShowDomainRequest - a model defined in huaweicloud sdk"""
        
        

        self._domain = None
        self.discriminator = None

        if domain is not None:
            self.domain = domain

    @property
    def domain(self):
        """Gets the domain of this ShowDomainRequest.

        直播域名，如果不设置此字段，则返回租户所有的域名信息

        :return: The domain of this ShowDomainRequest.
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this ShowDomainRequest.

        直播域名，如果不设置此字段，则返回租户所有的域名信息

        :param domain: The domain of this ShowDomainRequest.
        :type: str
        """
        self._domain = domain

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowDomainRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdklive-3.0.51-py2.py3-none-any.whl: huaweicloudsdklive/v1/model/show_domain_request.py <==
# coding: utf-8

import re
import six





class ShowDomainRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'domain': 'str'
    }

    attribute_map = {
        'domain': 'domain'
    }

    def __init__(self, domain=None):
        """ShowDomainRequest - a model defined in huaweicloud sdk"""
        
        

        self._domain = None
        self.discriminator = None

        if domain is not None:
            self.domain = domain

    @property
    def domain(self):
        """Gets the domain of this ShowDomainRequest.

        直播域名，如果不设置此字段，则返回租户所有的域名信息

        :return: The domain of this ShowDomainRequest.
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this ShowDomainRequest.

        直播域名，如果不设置此字段，则返回租户所有的域名信息

        :param domain: The domain of this ShowDomainRequest.
        :type: str
        """
        self._domain = domain

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowDomainRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
